@@ -3,7 +3,7 @@
     Smb4K.
                              -------------------
     begin                : Do Apr 2 2009
-    copyright            : (C) 2009-2019 by Alexander Reinholdt
+    copyright            : (C) 2009-2020 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -24,10 +24,6 @@
  *   MA 02110-1335, USA                                                    *
  ***************************************************************************/
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 // application specific includes
 #include "smb4kbasicnetworkitem.h"
 
@@ -43,6 +39,8 @@ class Smb4KBasicNetworkItemPrivate
     NetworkItem type;
     QIcon icon;
     QUrl url;
+    bool dnsDiscovered;
+    QString comment;
 };
 
 
@@ -54,11 +52,17 @@ Smb4KBasicNetworkItem::Smb4KBasicNetworkItem(NetworkItem type)
   // 
   d->type = type;
   
+  //
+  // Initialize the dnsDiscovered variable
+  // 
+  d->dnsDiscovered = false;
+  
   //
   // Initialize the protected variables
   // 
   pUrl = &d->url;
   pIcon = &d->icon;
+  pComment = &d->comment;
 }
 
 Smb4KBasicNetworkItem::Smb4KBasicNetworkItem(const Smb4KBasicNetworkItem &item)
@@ -74,6 +78,7 @@ Smb4KBasicNetworkItem::Smb4KBasicNetworkItem(const Smb4KBasicNetworkItem &item)
   // 
   pUrl = &d->url;
   pIcon = &d->icon;
+  pComment = &d->comment;
 }
 
 
@@ -171,3 +176,35 @@ QUrl Smb4KBasicNetworkItem::url() const
 }
 
 
+void Smb4KBasicNetworkItem::setDnsDiscovered(bool discovered)
+{
+  d->dnsDiscovered = discovered;
+}
+
+
+bool Smb4KBasicNetworkItem::dnsDiscovered() const
+{
+  return d->dnsDiscovered;
+}
+
+
+void Smb4KBasicNetworkItem::setComment(const QString& comment)
+{
+  d->comment = comment;
+}
+
+
+QString Smb4KBasicNetworkItem::comment() const
+{
+  return d->comment;
+}
+
+
+bool Smb4KBasicNetworkItem::hasUserInfo() const
+{
+  return !d->url.userInfo().isEmpty();
+}
+
+
+
+
