@@ -2,7 +2,7 @@
     This is the global namespace for Smb4K.
                              -------------------
     begin                : Sa Apr 2 2005
-    copyright            : (C) 2005-2019 by Alexander Reinholdt
+    copyright            : (C) 2005-2020 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -23,10 +23,6 @@
  *   MA 02110-1335, USA                                                    *
  ***************************************************************************/
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 // application specific includes
 #include "smb4kglobal.h"
 #include "smb4kglobal_p.h"
@@ -40,10 +36,17 @@
 #include <QUrl>
 #include <QStandardPaths>
 #include <QDebug>
+#include <QDirIterator>
 
 // KDE includes
 #include <KCoreAddons/KShell>
+#include <kio_version.h>
+#if KIO_VERSION < QT_VERSION_CHECK(5, 71, 0)
 #include <KIOWidgets/KRun>
+#else
+#include <KIO/OpenUrlJob>
+#include <KIO/CommandLauncherJob>
+#endif
 
 Q_GLOBAL_STATIC(Smb4KGlobalPrivate, p);
 QMutex mutex(QMutex::Recursive /* needed to avoid dead-locks */);
@@ -610,8 +613,7 @@ SharePtr Smb4KGlobal::findShareByPath(const QString &path)
   {
     for (const SharePtr &s : p->mountedSharesList)
     {
-      if (QString::compare(s->path(), path, Qt::CaseInsensitive) == 0 ||
-          QString::compare(s->canonicalPath(), path, Qt::CaseInsensitive) == 0)
+      if (QString::compare(s->path(), path, Qt::CaseInsensitive) == 0 || QString::compare(s->canonicalPath(), path, Qt::CaseInsensitive) == 0)
       {
         share = s;
         break;
@@ -635,11 +637,10 @@ QList<SharePtr> Smb4KGlobal::findShareByUrl(const QUrl &url)
   {
     for (const SharePtr &s : p->mountedSharesList)
     {
-      if (QString::compare(s->url().toString(QUrl::RemoveUserInfo|QUrl::RemovePort),
-                           url.toString(QUrl::RemoveUserInfo|QUrl::RemovePort),
-                           Qt::CaseInsensitive) == 0)
+      if (QString::compare(s->url().toString(QUrl::RemoveUserInfo|QUrl::RemovePort), url.toString(QUrl::RemoveUserInfo|QUrl::RemovePort), Qt::CaseInsensitive) == 0)
       {
         shares << s;
+        break;
       }
     }
   }
@@ -890,22 +891,36 @@ void Smb4KGlobal::openShare(SharePtr share, OpenWith openWith)
     case FileManager:
     {
       QUrl url = QUrl::fromLocalFile(share->canonicalPath());
-
+      
+#if KIO_VERSION < QT_VERSION_CHECK(5,71,0)
       (void) new KRun(url, 0);
+#else
+      KIO::OpenUrlJob *job = new KIO::OpenUrlJob(url);
+      job->setFollowRedirections(false);
+      job->setAutoDelete(true);
+      job->start();
+#endif
 
       break;
     }
     case Konsole:
     {
       QString konsole = QStandardPaths::findExecutable("konsole");
-
-      if (konsole.isEmpty())
+      
+      if (!konsole.isEmpty())
       {
-        Smb4KNotification::commandNotFound("konsole");
+#if KIO_VERSION < QT_VERSION_CHECK(5,71,0)
+        KRun::runCommand(konsole+" --workdir "+KShell::quoteArg(share->canonicalPath()), 0);
+#else
+        KIO::CommandLauncherJob *job = new KIO::CommandLauncherJob(konsole);
+        job->setWorkingDirectory(share->canonicalPath());
+        job->setAutoDelete(true);
+        job->start();
+#endif
       }
       else
       {
-        KRun::runCommand(konsole+" --workdir "+KShell::quoteArg(share->canonicalPath()), 0);
+        Smb4KNotification::commandNotFound("konsole");
       }
 
       break;
@@ -918,12 +933,19 @@ void Smb4KGlobal::openShare(SharePtr share, OpenWith openWith)
 }
 
 
-const QMap<QString,QString> &Smb4KGlobal::globalSambaOptions()
+const QString Smb4KGlobal::machineNetbiosName()
 {
-  return p->globalSambaOptions();
+  return p->machineNetbiosName;
 }
 
 
+const QString Smb4KGlobal::machineWorkgroupName()
+{
+  return p->machineWorkgroupName;
+}
+
+
+
 bool Smb4KGlobal::modifyCursor()
 {
   return p->modifyCursor;
@@ -931,9 +953,9 @@ bool Smb4KGlobal::modifyCursor()
 
 
 #if defined(Q_OS_LINUX)
-QStringList Smb4KGlobal::whitelistedMountArguments()
+QStringList Smb4KGlobal::allowedMountArguments()
 {
-  return p->whitelistedMountArguments;
+  return p->allowedMountArguments;
 }
 #endif
 
