@@ -2,7 +2,7 @@
     These are the private helper classes of the Smb4KGlobal namespace.
                              -------------------
     begin                : Di Jul 24 2007
-    copyright            : (C) 2007-2019 by Alexander Reinholdt
+    copyright            : (C) 2007-2020 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -79,11 +79,6 @@ class Smb4KGlobalPrivate : public QObject
      */
     QList<QSharedPointer<Smb4KShare>> sharesList;
     
-    /**
-     * The global options defined in smb.conf
-     */
-    const QMap<QString,QString> &globalSambaOptions(bool read = false);
-
     /**
      * Boolean that is TRUE when only foreign shares
      * are in the list of mounted shares
@@ -104,27 +99,27 @@ class Smb4KGlobalPrivate : public QObject
     
 #ifdef Q_OS_LINUX
     /**
-     * This list contains all whitelisted arguments for the mount.cifs binary and
+     * This list contains all allowed arguments for the mount.cifs binary and
      * is only present under the Linux operating system.
      */
-    QStringList whitelistedMountArguments;
+    QStringList allowedMountArguments;
 #endif
+    
+    /**
+     * The machine's NetBIOS name
+     */
+    QString machineNetbiosName;
+    
+    /**
+     * The machine's workgroup name
+     */
+    QString machineWorkgroupName;
 
   protected Q_SLOTS:
     /**
      * This slot does last things before the application quits
      */
     void slotAboutToQuit();
-    
-    /**
-     * Called when the smb.conf file is modified
-     */
-    void slotSmbConfModified(const QString &file);
-    
-  private:
-    QMap<QString,QString> m_sambaOptions;
-    bool m_sambaConfigMissing;
-    QFileSystemWatcher *m_watcher;
 };
 
 #endif
