@@ -3,7 +3,7 @@
     class.
                              -------------------
     begin                : Fr Okt 24 2008
-    copyright            : (C) 2008-2017 by Alexander Reinholdt
+    copyright            : (C) 2008-2019 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -29,7 +29,6 @@
 
 // application specific includes
 #include "smb4ksynchronizer.h"
-#include "smb4kprocess.h"
 #include "smb4kglobal.h"
 
 // Qt includes
@@ -39,6 +38,7 @@
 
 // KDE includes
 #include <KCoreAddons/KJob>
+#include <KCoreAddons/KProcess>
 #include <KIOWidgets/KUrlRequester>
 #include <KJobWidgets/KUiServerJobTracker>
     
@@ -58,30 +58,18 @@ class Smb4KSyncJob : public KJob
      */
     ~Smb4KSyncJob();
 
-    /**
-     * Returns TRUE if the job was started and FALSE
-     * otherwise
-     * 
-     * @returns TRUE if the job was started
-     */
-    bool isStarted() { return m_started; }
-
     /**
      * Starts the synchronization
      */
-    void start();
+    void start() override;
 
     /**
-     * Setup the synchronization process. You need to set the share, the parent
-     * widget is optional.
+     * Setup the synchronization process. This function must be 
+     * called before start() is run.
      *
-     * This function must be called before start() is run.
-     *
-     * @param src       The source
-     *
-     * @param dest      The destination
+     * @param share     The share
      */
-    void setupSynchronization(const SharePtr &share, QWidget *parent = 0);
+    void setupSynchronization(const SharePtr &share);
 
     /**
      * Returns the source directory.
@@ -119,7 +107,7 @@ class Smb4KSyncJob : public KJob
      * Reimplemented from KJob. Kills the internal process and
      * then the job itself.
      */
-    bool doKill();
+    bool doKill() override;
     
   protected Q_SLOTS:
     void slotStartSynchronization();
@@ -128,12 +116,10 @@ class Smb4KSyncJob : public KJob
     void slotProcessFinished(int exitCode, QProcess::ExitStatus status);
 
   private:
-    bool m_started;
     SharePtr m_share;
-    QWidget *m_parent_widget;
     QUrl m_src;
     QUrl m_dest;
-    Smb4KProcess *m_process;
+    KProcess *m_process;
     KUiServerJobTracker *m_job_tracker;
 };
 
