@@ -2,7 +2,7 @@
     Smb4K's container class for information about a workgroup.
                              -------------------
     begin                : Sa Jan 26 2008
-    copyright            : (C) 2008-2017 by Alexander Reinholdt
+    copyright            : (C) 2008-2020 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -23,10 +23,6 @@
  *   MA 02110-1335, USA                                                    *
  ***************************************************************************/
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 // application specific includes
 #include "smb4kworkgroup.h"
 #include "smb4kglobal.h"
@@ -127,6 +123,12 @@ QString Smb4KWorkgroup::masterBrowserName() const
 }
 
 
+bool Smb4KWorkgroup::hasMasterBrowser() const
+{
+  return !d->masterURL.host().isEmpty();
+}
+
+
 void Smb4KWorkgroup::setMasterBrowserIpAddress(const QString &ip)
 {
   d->masterIP.setAddress(ip);
@@ -161,10 +163,6 @@ void Smb4KWorkgroup::update(Smb4KWorkgroup* workgroup)
     setMasterBrowserName(workgroup->masterBrowserName());
     setMasterBrowserIpAddress(workgroup->masterBrowserIpAddress());
   }
-
-  
-  
-  
 }
 
 
