@@ -23,10 +23,6 @@
  *   MA 02110-1335, USA                                                    *
  ***************************************************************************/
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 // application specific includes
 #include "smb4kconfigpageauthentication.h"
 #include "core/smb4ksettings.h"
@@ -57,15 +53,12 @@ Smb4KConfigPageAuthentication::Smb4KConfigPageAuthentication(QWidget *parent) :
   // Layout 
   // 
   QVBoxLayout *layout = new QVBoxLayout(this);
-  layout->setSpacing(5);
-  layout->setMargin(0);
   
   //
   // Settings group box
   // 
   QGroupBox *settingsBox = new QGroupBox(i18n("Settings"), this);
   QVBoxLayout *settingsBoxLayout = new QVBoxLayout(settingsBox);
-  settingsBoxLayout->setSpacing(5);
   
   // Wallet usage
   QCheckBox *useWallet = new QCheckBox(Smb4KSettings::self()->useWalletItem()->label(), settingsBox);
@@ -90,7 +83,7 @@ Smb4KConfigPageAuthentication::Smb4KConfigPageAuthentication(QWidget *parent) :
   // 
   QGroupBox *walletEntriesBox = new QGroupBox(i18n("Wallet Entries"), this);
   QVBoxLayout *walletEntriesBoxLayout = new QVBoxLayout(walletEntriesBox);
-  walletEntriesBoxLayout->setSpacing(5);
+  walletEntriesBoxLayout->setContentsMargins(0, 0, 0, 0);
   
   //
   // Wallet Entries editor
@@ -98,7 +91,6 @@ Smb4KConfigPageAuthentication::Smb4KConfigPageAuthentication(QWidget *parent) :
   QWidget *walletEntriesEditor = new QWidget(walletEntriesBox);
   walletEntriesEditor->setObjectName("WalletEntriesEditor");
   QGridLayout *walletEntriesEditorLayout= new QGridLayout(walletEntriesEditor);
-  walletEntriesEditorLayout->setSpacing(5);
   
   // 
   // The list view 
@@ -133,7 +125,7 @@ Smb4KConfigPageAuthentication::Smb4KConfigPageAuthentication(QWidget *parent) :
   
   connect(walletEntriesWidget, SIGNAL(itemSelectionChanged()), this, SLOT(slotItemSelectionChanged()));
   
-  walletEntriesEditorLayout->addWidget(walletEntriesWidget, 0, 0, 7, 1, 0);
+  walletEntriesEditorLayout->addWidget(walletEntriesWidget, 0, 0, 7, 1);
   
   // 
   // Load button
@@ -146,7 +138,7 @@ Smb4KConfigPageAuthentication::Smb4KConfigPageAuthentication(QWidget *parent) :
   
   connect(loadButton, SIGNAL(clicked(bool)), this, SIGNAL(loadWalletEntries()));
   
-  walletEntriesEditorLayout->addWidget(loadButton, 0, 1, 0);
+  walletEntriesEditorLayout->addWidget(loadButton, 0, 1);
   
   // 
   // Save button
@@ -161,7 +153,7 @@ Smb4KConfigPageAuthentication::Smb4KConfigPageAuthentication(QWidget *parent) :
   connect(saveButton, SIGNAL(clicked(bool)), this, SIGNAL(saveWalletEntries()));
   connect(saveButton, SIGNAL(clicked(bool)), this, SLOT(slotSaveClicked(bool)));
   
-  walletEntriesEditorLayout->addWidget(saveButton, 1, 1, 0);
+  walletEntriesEditorLayout->addWidget(saveButton, 1, 1);
   walletEntriesEditorLayout->addItem(new QSpacerItem(0, 10, QSizePolicy::Fixed, QSizePolicy::Fixed), 2, 1);
   
   //
@@ -172,7 +164,6 @@ Smb4KConfigPageAuthentication::Smb4KConfigPageAuthentication(QWidget *parent) :
   detailsBox->setTitle(i18n("Details"));
   detailsBox->setEnabled(false);
   QVBoxLayout *detailsBoxLayout = new QVBoxLayout(detailsBox);
-  detailsBoxLayout->setSpacing(5);
   
   QTableWidget *detailsWidget = new QTableWidget(detailsBox);
   detailsWidget->setObjectName("DetailsWidget");
@@ -184,7 +175,7 @@ Smb4KConfigPageAuthentication::Smb4KConfigPageAuthentication(QWidget *parent) :
   
   detailsBoxLayout->addWidget(detailsWidget, 0);
   
-  walletEntriesEditorLayout->addWidget(detailsBox, 5, 1, 0);
+  walletEntriesEditorLayout->addWidget(detailsBox, 5, 1);
   walletEntriesEditorLayout->addItem(new QSpacerItem(0, 0, QSizePolicy::Fixed, QSizePolicy::MinimumExpanding), 6, 1);
   
   walletEntriesBoxLayout->addWidget(walletEntriesEditor, 0);
