@@ -287,14 +287,14 @@ void Smb4KMainWindow::setupView()
   //
   KConfigGroup configGroup(Smb4KSettings::self()->config(), "MainWindow");
 
-  if (!configGroup.exists())
-  {
+  if (!configGroup.hasKey(QStringLiteral("FirstStartup"))) {
     QList<QDockWidget *> docks = findChildren<QDockWidget *>();
-    
-    for (int i = 1; i < docks.size(); ++i)
-    {
-      tabifyDockWidget(docks.at(i-1), docks.at(i));
+
+    for (int i = 1; i < docks.size(); ++i) {
+      tabifyDockWidget(docks.at(i - 1), docks.at(i));
     }
+        
+    configGroup.writeEntry(QStringLiteral("FirstStartup"), true);
   }
 }
 
