@@ -2,7 +2,7 @@
     smb4knetworkbrowser  -  The network browser widget of Smb4K.
                              -------------------
     begin                : Mo Jan 8 2007
-    copyright            : (C) 2007-2019 by Alexander Reinholdt
+    copyright            : (C) 2007-2020 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -63,29 +63,11 @@ class Smb4KNetworkBrowser : public QTreeWidget
                   Type = 1,
                   IP = 2,
                   Comment = 3 };
-
+                  
     /**
-     * This function returns TRUE if the mouse is inside the network
-     * browser widget and FALSE otherwise.
-     *
-     * @returns TRUE if the mouse is inside the widget.
+     * The tooltip
      */
-    bool mouseInsideWidget() { return m_mouse_inside; }
-
-  signals:
-    /**
-     * This signal is emitted when a tool tip is about to be shown.
-     * 
-     * @param item          The network browser item
-     */
-    void aboutToShowToolTip(Smb4KNetworkBrowserItem *item);
-    
-    /**
-     * This signal is emitted when a tool tip is about to be hidden.
-     * 
-     * @param item          The network browser item
-     */
-    void aboutToHideToolTip(Smb4KNetworkBrowserItem *item);
+    Smb4KToolTip *toolTip();
 
   protected:
     /**
@@ -93,30 +75,6 @@ class Smb4KNetworkBrowser : public QTreeWidget
      */
     bool event(QEvent *e) override;
 
-    /**
-     * Reimplemented from QWidget. This function keeps track of the
-     * mouse position and handles the tool tips.
-     *
-     * @param e             The mouse event
-     */
-    void mouseMoveEvent(QMouseEvent *e) override;
-
-    /**
-     * Reimplemented from QWidget. This function emits the signal
-     * mouseOutside().
-     *
-     * @param e             The event object
-     */
-    void leaveEvent(QEvent *e) override;
-
-    /**
-     * Reimplemented from QWidget. This function emits the signal
-     * mouseInside().
-     *
-     * @param e             The event object
-     */
-    void enterEvent(QEvent *e) override;
-
     /**
      * Reimplemented from QAbstractItemView. This function handles
      * mouse press events.
@@ -124,39 +82,16 @@ class Smb4KNetworkBrowser : public QTreeWidget
      * @param e             The mouse event object
      */
     void mousePressEvent(QMouseEvent *e) override;
-
+    
     /**
-     * Reimplemented from QAbstractItemView. This function is used
-     * to stop the auto selection.
-     *
-     * @param e             The focus event
+     * Reimplemented from QAbstractItemView. This function handles
+     * mouse move events.
+     * 
+     * @param e             The mouse event object
      */
-    void focusOutEvent(QFocusEvent *e) override;
-
-    /**
-     * Reimplemented from QWidget. This function is used to handle
-     * the tooltip.
-     *
-     * @param e             The wheel event
-     */
-    void wheelEvent(QWheelEvent *e) override;
+    void mouseMoveEvent(QMouseEvent *e) override;
 
   protected slots:
-   /**
-     * This slot is used to change the cursor over an item if appropriate.
-     *
-     * @param item          The item that was entered.
-     *
-     * @param column        The column where the item was entered.
-     */
-    void slotItemEntered(QTreeWidgetItem *item, int column);
-
-    /**
-     * This slot is invoked when the viewport is entered. It is used
-     * to hide the tool tip if needed.
-     */
-    void slotViewportEntered();
-
     /**
      * This slot is called when the user activated an item. It is used
      * to open the item if it is expandable.
@@ -173,14 +108,9 @@ class Smb4KNetworkBrowser : public QTreeWidget
 
   private:
     /**
-     * The item for that a tool tip is shown
+     * The tool top widget
      */
-    Smb4KNetworkBrowserItem *m_tooltip_item;
-    
-    /**
-     * Mouse inside the widget?
-     */
-    bool m_mouse_inside;
+    Smb4KToolTip *m_toolTip;
 };
 
 #endif
