@@ -2,7 +2,7 @@
     smb4knetworkbrowseritem  -  Smb4K's network browser list item.
                              -------------------
     begin                : Mo Jan 8 2007
-    copyright            : (C) 2007-2019 by Alexander Reinholdt
+    copyright            : (C) 2007-2020 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -28,14 +28,21 @@
 
 // application specific includes
 #include "core/smb4kglobal.h"
-#include "smb4ktooltip.h"
 
 // Qt includes
 #include <QTreeWidgetItem>
 #include <QTreeWidget>
 
-
+// forward declarations
 class Smb4KNetworkBrowser;
+
+/**
+ * This class provides the items for the network neighborhood browser
+ * of Smb4K.
+ *
+ * @author Alexander Reinholdt <alexander.reinholdt@kdemail.net>
+ */
+
 class Smb4KNetworkBrowserItem : public QTreeWidgetItem
 {
   public:
@@ -105,23 +112,11 @@ class Smb4KNetworkBrowserItem : public QTreeWidgetItem
      */
     void update();
     
-    /**
-     * This function returns the tool tip of this item.
-     * 
-     * @returns the tool tip.
-     */
-    Smb4KToolTip *tooltip();
-
   private:
     /**
      * The network item
      */
     NetworkItemPtr m_item;
-    
-    /**
-     * The tool tip of this item
-     */
-    Smb4KToolTip *m_tooltip;
 };
 
 #endif
