@@ -1,8 +1,8 @@
 /***************************************************************************
     smb4ktooltip  -  Provides tooltips for Smb4K
                              -------------------
-    begin                : Sa Dez 23 2010
-    copyright            : (C) 2010-2017 by Alexander Reinholdt
+    begin                : Mi Mai 2020 
+    copyright            : (C) 2020 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -27,61 +27,92 @@
 #define SMB4KTOOLTIP_H
 
 // application specific includes
-#include "core/smb4kglobal.h"
+#include <smb4kglobal.h>
 
 // Qt includes
 #include <QPoint>
-#include <QWidget>
-#include <QGridLayout>
+#include <QWindow>
 #include <QHBoxLayout>
-#include <QVBoxLayout>
-#include <QLabel>
 
-// forward declarations
+// KDE includes
+#include <KWidgetsAddons/KToolTipWidget>
+
+// Forward declaration
 class Smb4KBasicNetworkItem;
 
-class Q_DECL_EXPORT Smb4KToolTip : public QWidget
+class Smb4KToolTip : public KToolTipWidget
 {
   Q_OBJECT
   
   public:
-    enum Parent { 
-      NetworkBrowser,
-      SharesView,
-      UnknownParent
-    };
-    explicit Smb4KToolTip(QWidget *parent = 0);
+    /**
+     * The constructor
+     */
+    Smb4KToolTip(QWidget *parent = nullptr);
+    
+    /**
+     * The destructor
+     */
     ~Smb4KToolTip();
-    void setup(Parent parent, const NetworkItemPtr &item);
-    void update(Parent parent, const NetworkItemPtr &item);
-    void show(const QPoint &pos);
-    void hide();
-    const NetworkItemPtr &networkItem() { return m_item; }
     
-  protected:
-    void paintEvent(QPaintEvent *e) override;
+    /**
+     * This enumeration determines the kind of tooltip 
+     * this is to be shown.
+     * 
+     * @enum NetworkItem  Tooltip reflecting a remote network item
+     * @enum MountedShare Tooltip reflecting a mounted share
+     */
+    enum Type {
+      NetworkItem,
+      MountedShare,
+      Unknown };
     
-  protected slots:
-    void slotHideToolTip();
+    /**
+     * Set up the tooltip. 
+     */
+    void setupToolTip(Type type, NetworkItemPtr item);
+    
+    /**
+     * Show the tooltip
+     */
+    void show(const QPoint &pos, QWindow *transientParent);
+    
+    /**
+     * Update the tooltip
+     */
+    void update();
     
   private:
+    /**
+     * Setup the contents widget for a remote network item
+     */
+    void setupNetworkItemContents();
+    
+    /**
+     * Setup the contents widget for a mounted share
+     */
+    void setupMountedShareContents();
+    
+    /**
+     * The network item
+     */
     NetworkItemPtr m_item;
-    QHBoxLayout *m_tip_layout;
-    QVBoxLayout *m_info_layout;
-    QGridLayout *m_text_layout;
-    void setupNetworkBrowserToolTip();
-    void updateNetworkBrowserToolTip();
-    void setupSharesViewToolTip();
-    void updateSharesViewToolTip();
-    static void arc(QPainterPath& path,
-                    qreal cx, qreal cy,
-                    qreal radius, qreal angle,
-                    qreal sweepLength);
-    QLabel *m_master_browser_label;
-    QLabel *m_comment_label;
-    QLabel *m_ip_label;
-    QLabel *m_mounted_label;
-    QLabel *m_size_label;
+    
+    /**
+     * The type
+     */
+    Type m_type;
+    
+    /**
+     * The contents widget for the tooltip
+     */
+    QWidget *m_contentsWidget;
+    
+    /**
+     * The main layout
+     */
+    QHBoxLayout *m_mainLayout;
 };
 
 #endif
+
